# ImageMetadataResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**architecture** | **str** | Target architecture of image |
**created** | **str** | Image creation date and time |
**digest** | **str** | Digest of the image |
**docker_version** | **str** | Version of Docker |
**env** | **list[str]** | Environment variables from analyzed image |
**labels** | **object** | Image labels |
**layers** | **list[str]** |  |
**os** | **str** | Operating system identifier |
**repo_tags** | **list[str]** |  |

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

